**********************************************************************
**********************************************************************
* Creating the proportional mapping matrices between SOC90 and SOC00
**********************************************************************
**********************************************************************

/* NOTE: 
This requires the following as inputs:
	1. $dir\markLFSmap - the proportional map supplied by Mark Williams (from job stayers in the LFS)
	2. $dir\9_onsmap.csv - the propotional map from my Excel spreadsheet, based on ONS data

It produces the following outputs - 3 sets of files, each one including an 'expand' file and a 'weights' file:
	LFS map from Mark Williams' data
		1. $workingdir\2_LFSmap_expand.dta
		2. $workingdir\2_LFSmap_weights.dta
	ONS map for both sexes combined
		3. $workingdir\2_map_expand_bothsex.dta
		4. $workingdir\2_map_weights_bothsex.dta
	ONS for each sex separately (i.e. SOC2000 to SOC90 conversion is different for men and women)
		5. $workingdir\2_map_expand_bysex.dta
		6. $workingdir\2_map_weights_bysex.dta
	
END OF NOTE */


////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Mark's LFS map
////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////

use "$dir\markLFSmap.dta", replace
ren tweight LFSwt
	label var LFSwt "Weight, from LFS (derived by Mark Williams)"
ren id 			match_id
ren maxid 		num_soc90
ren soc 		soc90_3I
ren soc2000		soc00_4

* Outputting the data file for EXPAND
preserve
	keep if match_id==1
	keep soc00_4 num_soc90 
	save "$workingdir\2_LFSmap_expand.dta", replace
restore

* Outputting the data file for MERGE
preserve
	keep soc00_4 soc90_3I match_id LFSwt
	save "$workingdir\2_LFSmap_weights.dta", replace
restore






////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////
// The ONS map
////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////

* Reading-in the proportional map that has been prepared in Excel (see Excel file for details of how to export the data)
clear
insheet using "$dir\9_onsmap.csv"
	drop if mwt==0 & fwt==0
	ren soc00 	soc00_4
	ren soc90 	soc90_3I
	label var soc90_3I "SOC90 imputed from SOC2000"
	ren titler 	titleR
	label var titleR "Title of regrouped SOC2000 (only 1/2 codes done - for others, see s/sheet"
	ren wtr 	recoded_wt
	label var recoded_wt "Weight for recoded data (where n for both genders combined < 30)"
	rename mwt 	wtM
	rename fwt 	wtF
	label var regrp_soc00 "Occupation for mapping - BBs hand-regrouped SOC00 to ensure all groups in the ONS mapping matrix have n>30"


	
	
	
////////////////////////////////////////////////////////////////////////////////////////////////////////////
// VERSION 1: Both sexes together - not currently used (14/10/10)
////////////////////////////////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////
// Small amount of additional work needed	

* ID variables
bysort soc00_4: gen match_id  = _n
bysort soc00_4: gen num_soc90 = _N
* Rescaling the weights to add to 1 for each soc00_4 code
bysort soc00_4: egen Mworking = total(wtM)
	gen Mscaledwt = wtM/Mworking
	label var Mscaledwt "Weight(men), rescaled"
bysort soc00_4: egen Fworking = total(wtF)
	gen Fscaledwt = wtF/Fworking
	label var Fscaledwt "Weight(women), rescaled"

//////////////////////////////////////////////////////
// Outputting datafiles

* Outputting the data file for EXPAND
preserve
	keep if match_id==1
	keep soc00_4 num_soc90 
	save "$workingdir\2_map_expand_bothsex.dta", replace
restore

* Outputting the data file for MERGE
preserve
	keep soc00_4 soc90_3I soc90_title match_id Mscaledwt Fscaledwt 
	save "$workingdir\2_map_weights_bothsex.dta", replace
restore






////////////////////////////////////////////////////////////////////////////////////////////////////////////
// VERSION 2: Split by sex AND using the regrouped soc00 coding to ensure n>30
////////////////////////////////////////////////////////////////////////////////////////////////////////////

capture drop match_id num_soc90 ?working ?scaledwt

//////////////////////////////////////////////////////
// Preparation 

* Changing the structure of the data file
gen socmatch_id = _n
reshape long wt, i(socmatch_id) j(gender) string
	encode gender, gen(gender_working)
	recode gender_working (1=2 "2_female") (2=1 "1_male"), gen(sex)
	drop gender gender_working

* Using the appropriate versions of the weights
*	This is necessary to ensure the different categories are weighted appropriately by their frequency in the ONS map
*	(I should really have done this in Excel, but easier to do this here in Stata)
replace wt = recoded_wt if soc00_4~=regrp_soc00
drop if wt==0

* Hand-merging the categories that have n<30 (the redefined groups are given in regrp_soc00)
preserve
	bysort soc00_4: keep if _n==1
	gen one = 1
	bysort regrp_soc00: egen regrp_n = total(one)
	bysort regrp_soc00 (soc00_4): gen resoc1 = cond(_n==1, soc00_4[2], soc00_4[1], .) if regrp_n>=2 & regrp_n<=4
	bysort regrp_soc00 (soc00_4): gen resoc2 = cond(_n==2, soc00_4[3], cond(_n==1, soc00_4[3], soc00_4[2], .), .) if regrp_n==3 | regrp_n==4
	bysort regrp_soc00 (soc00_4): gen resoc3 = cond(_n==4, soc00_4[3], soc00_4[4], .) if regrp_n==4 
	list soc00_4 regrp_soc00 regrp_n resoc1 resoc2 resoc3 if regrp_soc00~=soc00_4, sepby(regrp_soc00)
	keep soc00_4 regrp_n resoc?
	save "$workingdir\2_map_revocc.dta", replace
restore
merge m:1 soc00_4 using "$workingdir\2_map_revocc.dta"
expand regrp_n, gen(dup)
	bysort soc00_4 sex soc90_3I dup: gen dupno = sum(dup)
	clonevar soc00_4R = soc00_4
	replace soc00_4R = resoc1 if dupno==1
	replace soc00_4R = resoc2 if dupno==2
	replace soc00_4R = resoc3 if dupno==3
	* Checking that this has worked	
	sort soc00_4R sex soc90_3I dup
	list soc90_3I soc00_4 soc00_4R regrp_soc00 regrp_n resoc1 resoc2 resoc3 sex dup* wt if regrp_soc00==9924, sepby(soc00_4R)		// Four codes
	list soc90_3I soc00_4 soc00_4R regrp_soc00 regrp_n resoc1 resoc2 resoc3 sex dup* wt if regrp_soc00==9939, sepby(soc00_4R)		// Two codes
	list soc90_3I soc00_4 soc00_4R regrp_soc00 regrp_n resoc1 resoc2 resoc3 sex dup* wt if regrp_soc00==1112, sepby(soc00_4R)		// One code (unchanged)
	* Having checked this, overwrite the previous soc code
	ren soc00_4		old_soc00_4
	ren soc00_4R 	soc00_4

	
* Additional vars needed 
bysort soc00_4 sex: gen match_id  = _n
bysort soc00_4 sex: gen num_soc90 = _N

* Rescaling the weights to add to 1 for each soc00_4 code
bysort soc00_4 sex: egen working = total(wt)
	gen scaledwt = wt/working
	label var scaledwt "Weight, rescaled"
	drop working
	list soc00_4 old_soc00_4 soc90_3I regrp_soc00 sex dupno wt scaledwt if regrp_soc00==9924, sepby(soc00_4)


//////////////////////////////////////////////////////
// Outputting

* Outputting the data file for EXPAND
preserve
	keep if match_id==1
	keep sex soc00_4 num_soc90 
	save "$workingdir\2_map_expand_bysex.dta", replace
restore

* Outputting the data file for MERGE
preserve
	keep soc00_4 soc90_3I soc90_title match_id scaledwt regrp_soc00 sex
	save "$workingdir\2_map_weights_bysex.dta", replace
restore

